@@ -1,3 +1,4 @@
+# flake8: noqa: C901
 import os
 
 import click
@@ -32,8 +33,9 @@ def syslog_live_old(lockdown):
 @click.option('--nocolor', is_flag=True, help='disable colors')
 @click.option('--pid', type=click.INT, default=-1, help='pid to filter. -1 for all')
 @click.option('-m', '--match', help='match expression')
+@click.option('-i', '--insensitive', is_flag=True, help='treat the match expression as case insensitive')
 @click.option('include_label', '--label', is_flag=True, help='should include label')
-def syslog_live(lockdown, out, nocolor, pid, match, include_label):
+def syslog_live(lockdown, out, nocolor, pid, match, insensitive, include_label):
     """ view live syslog lines """
 
     log_level_colors = {
@@ -74,10 +76,19 @@ def syslog_live(lockdown, out, nocolor, pid, match, include_label):
             line_format += f' {label}'
 
         line = line_format.format(timestamp=timestamp, process_name=process_name, image_name=image_name, pid=pid,
-                                  level=level, label=label, message=message)
+                                  level=level, message=message)
 
-        if match and match not in line:
-            continue
+        if match is not None:
+            match_line = line
+            if insensitive:
+                match = match.lower()
+                match_line = line.lower()
+            if match not in match_line:
+                continue
+            else:
+                if not nocolor:
+                    match_line = match_line.replace(match, colored(match, attrs=['bold', 'underline']))
+                    line = match_line
 
         print(line)
 
