@@ -11,7 +11,7 @@ from pymobiledevice3 import usbmux
 from pymobiledevice3.ca import ca_do_everything
 from pymobiledevice3.exceptions import NoDeviceConnectedError, FatalPairingError, CannotStopSessionError, \
     NotTrustedError, \
-    PairingError, NotPairedError, StartServiceError, DeviceNonConnectedError
+    PairingError, NotPairedError, StartServiceError, DeviceNonConnectedError, PyMobileDevice3Exception
 from pymobiledevice3.service_connection import ServiceConnection
 
 
@@ -96,7 +96,7 @@ class LockdownClient(object):
             if self.unique_chip_id:
                 self.identifier = '%x' % self.unique_chip_id
             else:
-                raise Exception('Could not get UDID or ECID, failing')
+                raise PyMobileDevice3Exception('Could not get UDID or ECID, failing')
 
         if not self.validate_pairing():
             self.pair()
@@ -116,7 +116,7 @@ class LockdownClient(object):
         """
         version_reg = r'^\d*\.\d*\.?\d*$'
         if not re.match(version_reg, ios_version):
-            raise Exception('ios_version invalid:%s' % ios_version)
+            raise PyMobileDevice3Exception('ios_version invalid:%s' % ios_version)
         a = self.ios_version.split('.')
         b = ios_version.split('.')
         length = min(len(a), len(b))
@@ -224,11 +224,11 @@ class LockdownClient(object):
         self.logger.info('Creating host key & certificate')
         cert_pem, private_key_pem, device_certificate = ca_do_everything(self.device_public_key)
 
-        pair_record = {'DevicePublicKey': plistlib.Data(self.device_public_key),
-                       'DeviceCertificate': plistlib.Data(device_certificate),
-                       'HostCertificate': plistlib.Data(cert_pem),
+        pair_record = {'DevicePublicKey': self.device_public_key,
+                       'DeviceCertificate': device_certificate,
+                       'HostCertificate': cert_pem,
                        'HostID': self.host_id,
-                       'RootCertificate': plistlib.Data(cert_pem),
+                       'RootCertificate': cert_pem,
                        'SystemBUID': '30142955-444094379208051516'}
 
         pair = {'Label': self.label, 'Request': 'Pair', 'PairRecord': pair_record}
@@ -236,7 +236,7 @@ class LockdownClient(object):
         pair = self.service.recv_plist()
 
         if pair and (pair.get('Result') == 'Success') or ('EscrowBag' in pair):
-            pair_record['HostPrivateKey'] = plistlib.Data(private_key_pem)
+            pair_record['HostPrivateKey'] = private_key_pem
             pair_record['EscrowBag'] = pair.get('EscrowBag')
             write_home_file(HOMEFOLDER, '%s.plist' % self.identifier, plistlib.dumps(pair_record))
             self.paired = True
