@@ -1,6 +1,7 @@
 import plistlib
 import logging
 
+from pymobiledevice3.exceptions import PyMobileDevice3Exception
 from pymobiledevice3.lockdown import LockdownClient
 
 
@@ -16,11 +17,11 @@ class MobileConfigService(object):
         self.service.send_plist({'RequestType': 'GetProfileList'})
         response = self.service.recv_plist()
         if response.get('Status', None) != 'Acknowledged':
-            raise Exception(f'invalid response {response}')
+            raise PyMobileDevice3Exception(f'invalid response {response}')
         return response
 
     def install_profile(self, payload):
-        self.service.send_plist({'RequestType': 'InstallProfile', 'Payload': plistlib.Data(payload)})
+        self.service.send_plist({'RequestType': 'InstallProfile', 'Payload': payload})
         return self.service.recv_plist()
 
     def remove_profile(self, ident):
@@ -36,5 +37,5 @@ class MobileConfigService(object):
                                'PayloadUUID': meta['PayloadUUID'],
                                'PayloadVersion': meta['PayloadVersion']
                                })
-        self.service.send_plist({'RequestType': 'RemoveProfile', 'ProfileIdentifier': plistlib.Data(data)})
+        self.service.send_plist({'RequestType': 'RemoveProfile', 'ProfileIdentifier': data})
         return self.service.recv_plist()
